@@ -5,7 +5,7 @@ import numpy as np
 import pandas as pd
 
 
-class Radarfacerecog():
+class Radarfacerecog:
 
     def __init__(self):
         self.path = '/usr/local/lib/python3.8/site-packages/radarfacerecog/data/'
@@ -18,23 +18,27 @@ class Radarfacerecog():
             self.images.append(curimg)
             self.classnames.append(os.path.splitext(cl)[0])
 
-    def predict(self, image):
-        df = pd.read_csv('/usr/local/lib/python3.8/site-packages/radarfacerecog/politicos.csv')
-        apelidos = df['Apelido'].astype(str).tolist()
-        encodeListKnown = []
+    def find_encodigns(self):
+        encodeList = []
         for img in self.images:
             img = cv2.cvtColor(img, cv2.COLOR_BGR2RGB)
             encode = face_recognition.face_encodings(img)[0]
-            encodeListKnown.append(encode)
+            encodeList.append(encode)
+        
+        return encodeList
 
+    def predict(self, image):
+        df = pd.read_csv('/usr/local/lib/python3.8/site-packages/radarfacerecog/politicos.csv')
+        apelidos = df['Apelido'].astype(str).tolist()
+        encodeListKnow = self.find_encodigns(image)
         # For local running remove comment
         #unknowface = cv2.imread(image)
 
-        imgS = cv2.resize(image, (0, 0), None, 0.25, 0.25)
-        imgS = cv2.cvtColor(imgS, cv2.COLOR_BGR2RGB)
+        #imgS = cv2.resize(image, (0, 0), None, 0.25, 0.25)
+        #imgS = cv2.cvtColor(imgS, cv2.COLOR_BGR2RGB)
 
-        predict = face_recognition.face_locations(imgS)
-        encode_predict = face_recognition.face_encodings(imgS, predict)
+        predict = face_recognition.face_locations(image)
+        encode_predict = face_recognition.face_encodings(image, predict)
 
         for encodeFace, faceLoc in zip(encode_predict, predict):
             matches = face_recognition.compare_faces(
